@@ -29,14 +29,21 @@ def __parse_element__(element, name_parent_element, parent_element):
         parent_element[name_parent_element] = element.get('default')
 
 
-def __update_add_command__(params, template):
-    # TODO: сделать проверку на существование элемента и запрашивать перезапись
+def __update_add_command__(**kwargs):
+    params = kwargs['params']
+    template = kwargs['template']
     with open(params.config_file, 'r') as config_file:
         config = json_load(config_file.read())
     for i in params.elements:
         if i not in template['properties']:
             print(f'Элемента {i} нет в шаблоне')
             return
+        if i in config.keys():
+            # TODO: сделать метод для ожидания ввода
+            print(f'{i} элемент уже есть в конфигурации, перезаписать (y/n)')
+            answer = input()
+            if answer.lower() != "yes" and answer.lower() != 'y':
+                continue
         global new_element
         new_element = {}
         __parse_element__(template['properties'][i], i, new_element)
@@ -46,7 +53,8 @@ def __update_add_command__(params, template):
     print(f"{'Элемент добавлен' if len(params.elements) == 1 else 'Элементы добавлены'}")
 
 
-def __update_delete_command__(params, template):
+def __update_delete_command__(**kwargs):
+    params = kwargs['params']
     with open(params.config_file, 'r') as config_file:
         config = json_load(config_file.read())
 
@@ -157,13 +165,12 @@ def update_command(params):
         print("Указанного файла не существует")
         return
 
-    # TODO: в удаление шаблон не используется исправить
     template = json_load(open(getenv("TEMPLATE_CONFIG")).read())
     update_methods = {
         "add": __update_add_command__,
         "delete": __update_delete_command__
     }
-    update_methods[params.update_command](params, template)
+    update_methods[params.update_command](params=params, template=template)
 
 
 methods = {
